@@ -1,15 +1,11 @@
-from . import mixins
 from .__version__ import __version__
 from .HowFairIsChecker import HowFairIsChecker
-from .Platform import Platform
 
 
 __author__ = "https://github.com/jspaaks"
 __email__ = 'j.spaaks@esciencecenter.nl'
 
 __all__ = [
-    "HowFairIsChecker",
-    "Platform",
-    "mixins",
-    "__version__"
+    "__version__",
+    "HowFairIsChecker"
 ]
